(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "lodash"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var lodash_1 = require("lodash");
    var DEFAULT_REPLACE_CONFIG = {
        target: '</head>',
    };
    var Plugin = /** @class */ (function () {
        function Plugin(config) {
            if (config === void 0) { config = {}; }
            this.config = config;
            this.css = {};
        }
        Plugin.addStyle = function (html, style, replaceConfig) {
            var styleString = "<style type=\"text/css\">" + style + "</style>";
            var replaceValues = [styleString, replaceConfig.target];
            if (replaceConfig.position === 'after') {
                replaceValues.reverse();
            }
            return html.replace(replaceConfig.target, replaceValues.join(''));
        };
        Plugin.removeLinkTag = function (html, cssFileName) {
            return html.replace(new RegExp("<link[^>]+href=['\"]" + cssFileName + "['\"][^>]+(>|/>|></link>)", 'g'), '');
        };
        Plugin.cleanUp = function (html, replaceConfig) {
            return replaceConfig.removeTarget
                ? html.replace(replaceConfig.target, '')
                : html;
        };
        Plugin.prototype.getCSSFile = function (cssLink, publicPath) {
            // Link pattern: publicPath + fileName + '?' + hash
            var fileName = cssLink
                .replace(new RegExp("^" + lodash_1.escapeRegExp(publicPath)), '')
                .replace(/\?.+$/g, '');
            return this.css[fileName];
        };
        Plugin.prototype.isCurrentFileNeedsToBeInlined = function (fileName) {
            if (typeof this.config.filter === 'function') {
                return this.config.filter(fileName);
            }
            else {
                return true;
            }
        };
        Plugin.prototype.prepare = function (_a) {
            var _this = this;
            var assets = _a.assets;
            var isCSS = is('css');
            Object.keys(assets).forEach(function (fileName) {
                if (isCSS(fileName) && _this.isCurrentFileNeedsToBeInlined(fileName)) {
                    _this.css[fileName] = assets[fileName].source();
                    if (!_this.config.leaveCSSFile) {
                        delete assets[fileName];
                    }
                }
            });
        };
        Plugin.prototype.process = function (data) {
            var _this = this;
            var _a = this.config.replace, replaceConfig = _a === void 0 ? DEFAULT_REPLACE_CONFIG : _a;
            // check if current html needs to be inlined
            if (this.isCurrentFileNeedsToBeInlined(data.outputName)) {
                data.assets.css.forEach(function (cssLink) {
                    data.html = Plugin.addStyle(data.html, _this.getCSSFile(cssLink, data.assets.publicPath), replaceConfig);
                });
                data.html = Plugin.cleanUp(data.html, replaceConfig);
                data.assets.css.length = 0; // prevent generate <link /> tag
            }
        };
        Plugin.prototype.apply = function (compiler) {
            var _this = this;
            compiler.hooks.compilation.tap('html-inline-css-webpack-plugin', function (compilation) {
                if ('htmlWebpackPluginBeforeHtmlProcessing' in compilation.hooks) {
                    var hook = 
                    // @ts-ignore Error:(130, 27) TS2339: Property 'htmlWebpackPluginBeforeHtmlProcessing' does not exist on type 'CompilationHooks'.
                    compilation.hooks.htmlWebpackPluginBeforeHtmlProcessing;
                    hook.tap('html-inline-css-webpack-plugin-html-webpack-plugin-before-html-processing', function (data) {
                        _this.prepare(compilation);
                        _this.process(data);
                    });
                }
                else {
                    throw new Error('`html-webpack-plugin` should be ordered first before html-inline-css-webpack-plugin');
                }
            });
        };
        return Plugin;
    }());
    exports.default = Plugin;
    function is(filenameExtension) {
        var reg = new RegExp("." + filenameExtension + "$");
        return function (fileName) { return reg.test(fileName); };
    }
});
//# sourceMappingURL=index.js.map